"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useInputEditor = useInputEditor;
function useInputEditor() {
  const primeInputWithOptionNames = ["CascadeSelect", "Listbox", "MultiSelect", "RadioButton", "Select", "SelectButton", "TreeSelect"];
  const primeInputNames = [...primeInputWithOptionNames, "AutoComplete", "Checkbox", "ColorPicker", "DatePicker", "Editor", "InputMask", "InputNumber", "InputOtp", "InputText", "Knob", "Password", "Rating", "Slider", "Textarea", "ToggleButton", "ToggleSwitch"].sort();
  const primeOutputNames = ["OutputBoolean", "OutputDate", "OutputDuration", "OutputLink", "OutputList", "OutputNumber", "OutputReference", "OutputText"];
  function editorDataToSchema(data) {
    if (!data) return {};
    const formkitInput = data?._dollar_formkit;
    let tempData = {};
    if (data.prime && data.prime?.length > 0) {
      const mapped = data.prime?.map(entry => {
        const key = entry.prime_key;
        let value = entry.prime_value;
        if (formkitInput === "primeInputOtp" && key === "length") value = +value;
        return [key, value];
      });
      tempData = Object.assign(...mapped.map(([key, val]) => ({
        [key]: val
      })));
    }
    const readonlyValue = data.readonly ? true : void 0;
    const disabledValue = data.disabled ? true : void 0;
    const preserveValue = data.preserve ? true : void 0;
    const defaultObject = {
      readonly: readonlyValue,
      disabled: disabledValue,
      preserve: preserveValue
    };
    let outerClass = "";
    if (data.outerClass) outerClass = `${outerClass} ${data.outerClass}`.trim();
    let wrapperClass = "";
    if (data.wrapperClass) wrapperClass = `${wrapperClass} ${data.wrapperClass}`.trim();
    let innerClass = "";
    if (data.innerClass) innerClass = `${innerClass} ${data.innerClass}`.trim();
    const undefinedObject = {
      prime: void 0,
      schemaResultFormKey: void 0,
      _dollar_formkit: void 0,
      slots: void 0,
      selectButton: void 0
    };
    const useOptions = primeInputWithOptionNames.map(s => `prime${s}`).includes(formkitInput);
    let result = {};
    if (useOptions) result = {
      ...data,
      $formkit: formkitInput,
      ...tempData,
      ...undefinedObject,
      ...defaultObject,
      outerClass,
      wrapperClass,
      innerClass,
      optionLabel: "label",
      optionValue: "value"
    };else result = {
      ...data,
      $formkit: formkitInput,
      ...tempData,
      ...undefinedObject,
      ...defaultObject,
      outerClass,
      wrapperClass,
      innerClass,
      options: void 0
    };
    for (const key in result) {
      const value = result[key];
      if (typeof value === "string" || value instanceof String) {
        if (value.trim().length === 0) result[key] = void 0;
      }
    }
    return result;
  }
  function dataToSchema(data) {
    const schema = editorDataToSchema(data);
    if (schema.options) {
      const options = schema.options.map(o => JSON.parse(JSON.stringify(o)));
      return {
        ...schema,
        options
      };
    } else {
      return schema;
    }
  }
  function editorDataToJson(data) {
    return JSON.stringify(dataToSchema(data));
  }
  function objectToString(data) {
    return `{${Object.entries(data).map(([key, value]) => {
      if (key === "options" && value.length > 0) {
        let result = "[";
        value.forEach(o => result = `${result + objectToString(o)}, `);
        return `${key}: ${result.substring(0, result.length - 2)}]`;
      } else if (key === "primeInputOtp") {
        return `${key}: ${value}`;
      } else {
        return `${key}: '${value}'`;
      }
    }).join()}}`;
  }
  function editorDataToObject(data) {
    return objectToString(JSON.parse(editorDataToJson(data)));
  }
  function schemaToEditorData(schema) {
    const formkitInput = schema?.$formkit;
    return {
      ...schema,
      _dollar_formkit: formkitInput
    };
  }
  return {
    primeInputNames,
    primeOutputNames,
    editorDataToSchema,
    editorDataToJson,
    editorDataToCode: editorDataToObject,
    schemaToEditorData
  };
}